vexmpp\.vex package
===================

Submodules
----------

vexmpp\.vex\.util module
------------------------

.. automodule:: vexmpp.vex.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vexmpp.vex
    :members:
    :undoc-members:
    :show-inheritance:
